@@ -3,7 +3,7 @@ package HTTP::Headers;
 use strict;
 use warnings;
 
-our $VERSION = '6.21'; # TRIAL
+our $VERSION = '6.23'; # TRIAL
 
 use Carp ();
 
@@ -299,8 +299,8 @@ sub _process_newline {
 
 
 
-if (eval { require Storable; 1 }) {
-    *clone = \&Storable::dclone;
+if (eval { require Clone; 1 }) {
+    *clone = \&Clone::clone;
 } else {
     *clone = sub {
 	my $self = shift;
@@ -475,7 +475,7 @@ HTTP::Headers - Class encapsulating HTTP Message headers
 
 =head1 VERSION
 
-version 6.21
+version 6.23
 
 =head1 SYNOPSIS
 
@@ -535,7 +535,8 @@ means that you can update several fields with a single invocation.
 The $value argument may be a plain string or a reference to an array
 of strings for a multi-valued field. If the $value is provided as
 C<undef> then the field is removed.  If the $value is not given, then
-that header field will remain unchanged.
+that header field will remain unchanged. In addition to being a string,
+$value may be something that stringifies.
 
 The old value (or values) of the last of the header fields is returned.
 If no such field exists C<undef> will be returned.
@@ -876,7 +877,7 @@ Gisle Aas <gisle@activestate.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 1994-2017 by Gisle Aas.
+This software is copyright (c) 1994 by Gisle Aas.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
